﻿namespace UltraGridAppearance
{
    using System;
    using System.Data;
    using System.Drawing;
    using System.Windows.Forms;
    using Infragistics.Win;
    using Infragistics.Win.UltraWinGrid;
    public partial class Form1 : Form
    {
        private Infragistics.Win.Appearance columnApp;
        private Infragistics.Win.Appearance selectedRowApp;

        public Form1()
        {
            InitializeComponent();

            // reuse the appearances in order to save resources
            this.columnApp = new Infragistics.Win.Appearance();
            this.columnApp.BackColor = Color.Red;
            this.columnApp.ForeColor = Color.White;

            this.selectedRowApp = new Infragistics.Win.Appearance();
            this.selectedRowApp.BackColor = Color.Green;
            this.selectedRowApp.ForeColor = Color.Yellow;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            this.ultraGrid1.InitializeLayout += UltraGrid1_InitializeLayout;
            this.ultraGrid1.InitializeRow += UltraGrid1_InitializeRow;
            this.ultraGrid1.BeforeSelectChange += UltraGrid1_BeforeSelectChange;

            this.ultraGrid1.SetDataBinding(this.GetData(), null);
        }

        private void UltraGrid1_BeforeSelectChange(object sender, BeforeSelectChangeEventArgs e)
        {
            // if the selection is row reset the appearance of the old selected rows and set it to the new once
            if (e.Type.Name == "UltraGridRow")
            {
                foreach (var row in this.ultraGrid1.Selected.Rows)
                {
                    row.Appearance.Reset();
                }

                foreach (var row in e.NewSelections.Rows)
                {
                    row.Appearance = (Infragistics.Win.Appearance)this.selectedRowApp.Clone();
                }
            }
        }

        private void UltraGrid1_InitializeLayout(object sender, InitializeLayoutEventArgs e)
        {
            // remove the default selected and active row appearance
            // otherwise they will override the cell appearance
            e.Layout.Override.SelectedAppearancesEnabled = DefaultableBoolean.False;
            e.Layout.Override.ActiveAppearancesEnabled = DefaultableBoolean.False;

            // by default column headers are with applied ThemedElementAlpha
            // we need to set this to transparent in order to be able to apply any appearance
            var colWithCustomHeader = e.Layout.Bands[0].Columns[4].Header;
            colWithCustomHeader.Appearance.ThemedElementAlpha = Alpha.Transparent;
            colWithCustomHeader.Appearance.BackColor = Color.Orange;

            e.Layout.PerformAutoResizeColumns(true, PerformAutoSizeType.AllRowsInBand);
        }

        private void UltraGrid1_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            // set the cell appearance for the necessary columns.
            // this will override the row appearance
            foreach (var cell in e.Row.Cells)
            {
                if (cell.Column.Index % 4 == 2)
                {
                    cell.Appearance = this.columnApp;
                }
            }
        }

        private object GetData(int rows = 20, int cols = 10)
        {
            DataTable dt = new DataTable();

            for (int col = 0; col < cols; col++)
            {
                dt.Columns.Add(string.Format("Column #{0}", col + 1));
            }

            for (int row = 0; row < rows; row++)
            {
                DataRow addRow = dt.NewRow();
                foreach (DataColumn column in dt.Columns)
                {
                    addRow[column] = string.Format("{0}.{1}", row + 1, column.Ordinal + 1);
                }

                dt.Rows.Add(addRow);
            }

            return dt;
        }
    }
}
